class basisset:
	def basis(self, gbasis='sto3g'):
		sto3g =' $basis gbasis=sto ngauss=3 $end\n'
		g321  =' $basis gbasis=N21 ngauss=3 $end\n'
                g631d =' $basis gbasis=N31 ngauss=6 ndfunc=1 $end\n'
                g631dp=' $basis gbasis=N31 ngauss=6 ndfunc=1 npfunc=1 $end\n'
                g631plusdp=' $basis gbasis=N31 ngauss=6 $end\n'+ \
                            ' $basis ndfunc=1 npfunc=1 diffsp=.true. $end\n'
                g631doubleplusdp =' $basis gbasis=N31 ngauss=6 $end\n'+ \
                            ' $basis ndfunc=1 npfunc=1 $end\n' +\
                            ' $basis diffsp=.true. diffs=.true. $end\n'
                sbkjc = ' $basis gbasis=sbk ngauss=3 ndfunc=1 $end\n'+\
                        ' $contrl ecp=sbk $end\n'

                hw = ' $basis gbasis=hw ndfunc=1 $end\n' +\
                    '$contrl ecp=hw $end'

		card={
			'STO3G'  : sto3g,
			'STO-3G' : sto3g,

			'321G'   : g321,
			'3-21G'  : g321,


                        '631GD' : g631d,
                        '6-31GD' : g631d,
                        '6-31G(D)': g631d,
                        '631G(D)': g631d,
                        '631G*' : g631d,
                        '6-31G*' : g631d,

                        '631GDP': g631dp,
                        '6-31GDP':g631dp,
                        '631G(D,P)' : g631dp,
                        '6-31G(D,P)' : g631dp,
                        '631G**' : g631dp,
                        '6-31G**' : g631dp,

                        '631++GDP' : g631doubleplusdp,
                        '631++GDP' : g631doubleplusdp,
                        '631++G(D,P)' : g631doubleplusdp,
                        '6-31++G(D,P)' : g631doubleplusdp,
                        '631++G**' : g631doubleplusdp,
                        '631++G**' : g631doubleplusdp,

                        'SBKJC': sbkjc,
                        'HW': hw,
		}

		self.__basis__ = card[gbasis.upper()]



def dat2irc(filename="mol.dat"):
    f=open(filename)
    content=f.read()
    f.close()

    header=" $contrl runtyp=irc $end\n"
    forward=" $irc saddle=.true. npoint=10 forwrd=.true. $end\n"
    backward=" $irc saddle=.true. npoint=10 forwrd=.false. $end\n"
    irc_forward=header + forward + content
    irc_backward=header + backward +content

    out=open("mol_ircfor.inp", 'w')
    out.write(irc_forward)
    out.close()

    out=open("mol_ircbak.inp", 'w')
    out.write(irc_backward)
    out.close()



class output:
	def writefile(self, outfile="mol.inp"):
		data=''
		data += self.__purpose__
		data +=self.__method__
		data +=self.__basis__
		data +=self.__data__
		f=open(outfile, 'w')
		f.write(data)
		f.close()



import setuptools

with open("README.md", "r") as fh:
    long_description=fh.read()

setuptools.setup(
        name="gmsfile",
        version="0.0.6",
        author="Gourab Kanti Das",
        author_email="gourabkanti.das@visva-bharati.ac.in",
        description="A converter from XYZ to GAMESS file",
        long_description=long_description,
        long_description_content_type="text/markdown",
        url="https://github.com/drylab/gmsfile",
        packages = setuptools.find_packages(),
        classifiers=[
            "Programming Language :: Python :: 2.7",
            "License :: OSI Approved :: MIT License",
            "Operating System :: OS Independent",
        ],
        python_requires='>=2.7',
)



class purpose:

	def runtyp(self, purpose='opt'):

		energy=' $contrl runtyp=energy $end\n'

		opt   =' $contrl runtyp=optimize $end\n'+ \
		       ' $statpt opttol=0.0001 nstep=100 $end\n'

		freq  =' $contrl runtyp=hessian $end\n'+ \
		       ' $force method=analytic vibanl=.true. $end\n'

                sadpoint=' $contrl runtyp=sadpoint $end\n' +\
                         " $force method=analytic $end\n" +\
		         ' $statpt opttol=0.0001 nstep=30 hess=calc $end\n'

		card= {
			'ENERGY':energy,
			'OPT'   :opt, 
			'FREQ'  :freq, 
			'SADPOINT'   :sadpoint,
			}
		self.__purpose__= card[purpose.upper()]



class method:
	def method(self, type="rhf"):

		rhf   = ' $contrl scftyp=rhf maxit=100 $end\n'
		uhf   = ' $contrl scftyp=uhf maxit=100 $end\n'
		rohf  = ' $contrl scftyp=rohf maxit=100 $end\n'

		list={
			'RHF' :rhf,
			'UHF' :uhf,
			'ROHF':rohf,
		}
		self.__method__=list[type.upper()]
